pub enum CoordinatorToWorkerMsg {
WorkUnitBatch(WorkUnitBatch),
WorkUnitEos,
}Variants
WorkUnitBatch(WorkUnitBatch)
A batch of messages from a work unit feed belonging to different partitions from one node from the plan set in set_plan_request. A work unit feed is a per-partition stream of information that tells the node what should be executed within a partition, for example, a stream of file addresses that should be read.
WorkUnitEos
Signals an EOS for WorkUnits. After this message is received, no more WorkUnits will be sent.