pub enum DistributedMetricsFormat {
Aggregated,
PerTask,
}Expand description
Format to use when displaying metrics for a distributed plan.
Variants
Aggregated
Metrics are aggregated across all tasks. ex. a output_rows=X represents the output rows for all tasks.
PerTask
Metrics are labeled with their task id and displayed per task. ex. output_rows is shown as
output_rows={0:.., 1:..}, one entry per task.