pub enum MaybeEncoded<T> {
Encoded(Vec<u8>),
Decoded(T),
}Expand description
A value that a transport may either leave encoded or materialize in memory. Users are free to pass MaybeEncoded::Encoded or MaybeEncoded::Decoded at any moment and Distributed DataFusion’s code will internally know how to handle it.
Variants
Implementations
Sourceimpl MaybeEncoded<Arc<dyn ExecutionPlan>>
impl MaybeEncoded<Arc<dyn ExecutionPlan>>
Sourcepub fn encode(self, ctx: &Arc<TaskContext>) -> Result<Vec<u8>>
pub fn encode(self, ctx: &Arc<TaskContext>) -> Result<Vec<u8>>
Returns the encoded ExecutionPlan as protobuf bytes:
- If in
Decodedstate, it encodes it using the codecs registered in the TaskContext. - If in
Encodedstate, it just passes through the content.
Sourceimpl MaybeEncoded<Partitioning>
impl MaybeEncoded<Partitioning>
Sourcepub fn encode(self, ctx: &Arc<TaskContext>) -> Result<Vec<u8>>
pub fn encode(self, ctx: &Arc<TaskContext>) -> Result<Vec<u8>>
Returns the encoded Partitioning as protobuf bytes:
- If in
Decodedstate, it encodes it using the codecs registered in the TaskContext. - If in
Encodedstate, it just passes through the content.
Sourcepub fn decode(
self,
schema: SchemaRef,
task_ctx: &TaskContext,
) -> Result<Partitioning>
pub fn decode( self, schema: SchemaRef, task_ctx: &TaskContext, ) -> Result<Partitioning>
Returns the decoded Partitioning.
- If in
Decodedstate, it just passes through the content. - If in
Encodedstate, it decodes it using the codecs registered in the TaskContext.