pub enum ProducerHead {
None,
BroadcastExec {
output_partitions: usize,
},
RepartitionExec {
partitioning: MaybeEncoded<Partitioning>,
},
}Expand description
Defines what shape should the head node of a stage have upon getting executed. Depending on the NetworkBoundary implementation, the stage below should have different head nodes.
Variants
None
No specific head node is necessary.
BroadcastExec
The head node should be a BroadcastExec.
RepartitionExec
The head node should be a RepartitionExec.
Fields

partitioning: MaybeEncoded<Partitioning>Trait Implementations
Sourceimpl Clone for ProducerHead
impl Clone for ProducerHead
Sourcefn clone(&self) -> ProducerHead
fn clone(&self) -> ProducerHead
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl !RefUnwindSafe for ProducerHead
impl !UnwindSafe for ProducerHead
impl Freeze for ProducerHead
impl Send for ProducerHead
impl Sync for ProducerHead
impl Unpin for ProducerHead
impl UnsafeUnpin for ProducerHead