pub enum TaskCountAnnotation {
Desired(usize),
Maximum(usize),
}Expand description
Annotation attached to a single ExecutionPlan that determines how many distributed tasks it should run on.
Variants
Desired(usize)
The desired number of distributed tasks for this node. The final task count for the annotated node might not be exactly this number, it is more like a hint, so depending on the desired task count of adjacent nodes, the final task count might change.
Maximum(usize)
Sets a maximum number of distributed tasks for this node. Typically used with the inner value of 1, stating that this node cannot be executed in a distributed fashion.
Implementations