pub enum WorkerToCoordinatorMsg {
TaskMetrics(TaskMetrics),
LoadInfo(LoadInfo),
LoadInfoEos,
}Variants
TaskMetrics(TaskMetrics)
Sends the metrics collected during task execution back to the coordinator. This is sent after all partitions of a task have finished (or been dropped), ensuring metrics are never lost due to early stream termination. metrics[i] is the set of metrics for plan node i in pre-order traversal order.
LoadInfo(LoadInfo)
Load information reported by a task. This information is used for dynamically sizing the number of workers involved in a query.
LoadInfoEos