rewrite_distributed_plan_with_metrics

Function rewrite_distributed_plan_with_metrics 

pub async fn rewrite_distributed_plan_with_metrics(
    plan: Arc<dyn ExecutionPlan>,
    format: DistributedMetricsFormat,
) -> Result<Arc<dyn ExecutionPlan>>
Rewrites a distributed plan with metrics. Does nothing if the root node is not a DistributedExec. Returns an error if the distributed plan was not executed.

Waits for all worker task metrics to arrive before rewriting, so the result is always complete.