Module grpc

Module grpc 

Structs

DefaultChannelResolver
Default implementation of a ChannelResolver that connects to the workers given the URL once and stores the connection instance in a TTI cache.
GetClusterWorkersRequest
GetClusterWorkersResponse
GetTaskProgressRequest
GetTaskProgressResponse
ObservabilityServiceClient
ObservabilityServiceImpl
ObservabilityServiceServer
PingRequest
PingResponse
TaskProgress
Progress information for a single task
WorkerMetrics
Worker-level system metrics

Enums

TaskStatus

Traits

ObservabilityService
Generated trait containing gRPC methods that should be implemented for use with ObservabilityServiceServer.

Functions

create_worker_client
Creates a [WorkerServiceClient] with high default message size limits.

Type Aliases

BoxCloneSyncChannel