BroadcastExec

Struct BroadcastExec 

pub struct BroadcastExec { /* private fields */ }
ExecutionPlan that scales up partitions for network broadcasting.

This plan takes N input partitions and exposes N*M output partitions, where M is the number of consumer tasks. Each virtual partition i returns the cached result of input partition i % N.

This allows each consumer task to fetch a unique set of partition numbers, the virtual partitions, while all receiving the same data via the actual partitions. This structure maintains the invariant that each partition is executed exactly once by the framework.

Broadcast is used in a 1 to many context, like this:

┌────────────────────────┐      ┌────────────────────────┐                         ┌────────────────────────┐     ■
│  NetworkBroadcastExec  │      │  NetworkBroadcastExec  │           ...           │  NetworkBroadcastExec  │     │
│        (task 1)        │      │        (task 2)        │                         │        (task M)        │ Stage N+1
└┬─┬─────┬───┬───────────┘      └───────┬─┬─────┬────┬───┘                         └─────┬──────┬─────┬────┬┘     │
 │0│     │N-1│                          │N│     │2N-1│                                   │(M-1)N│     │MN-1│      │
 └▲┘ ... └▲──┘                          └▲┘ ... └──▲─┘                                   └───▲──┘ ... └──▲─┘      ■
  │       │     Populates                │         │                                         │           │
  │       └────Cache Index ───┐     Cache Hit   Cache Hit                    ┌──Cache Hit────┘           │
  │                N-1        │      Index 0    Index N-1                    │                           │
  └────Populates ─────┐       │          │         │                         │            ┌───Cache Hit──┘
     Cache Index 0    │       │          │         │                         │            │
                     ┌┴┐ ... ┌┴──┐      ┌┴┐ ... ┌──┴─┐        ...        ┌───┴──┐ ... ┌───┴┐                      ■
                     │0│     │N-1│      │N│     │2N-1│                   │(M-1)N│     │MN-1│                      │
                    ┌┴─┴─────┴───┴──────┴─┴─────┴────┴───────────────────┴──────┴─────┴────┴┐                     │
                    │                             BroadcastExec                             │                     │
                    │                     ┌───────────────────────────┐                     │                     │
                    │                     │        Batch Cache        │                     │                  Stage N
                    │                     │┌─────────┐     ┌─────────┐│                     │                     │
                    │                     ││ index 0 │ ... │index N-1││                     │                     │
                    │                     │└─────────┘     └─────────┘│                     │                     │
                    │                     └───────────────────────────┘                     │                     │
                    └───────────────────────────┬─┬──────────┬───┬──────────────────────────┘                     ■
                                                │0│          │N-1│
                                                └▲┘    ...   └─▲─┘
                                                 │             │
                                              ┌──┘             └──┐
                                              │                   │                                               ■
                                             ┌┴┐       ...     ┌──┴┐                                              │
                                             │0│               │N-1│                                          Stage N-1
                                            ┌┴─┴───────────────┴───┴┐                                             │
                                            │Arc<dyn ExecutionPlan> │                                             │
                                            └───────────────────────┘                                             ■

Notice that the first consumer task, [NetworkBroadcastExec] task 1, triggers the execution of the operator below the [BroadCastExec] and populates each cache index with the respective partition. Subsequent consumer tasks, rather than executing the same partitions, read the data from the cache for each partition.

Implementations

Source

impl BroadcastExec

pub fn new(input: Arc<dyn ExecutionPlan>, consumer_task_count: usize) -> Self

pub fn input_partition_count(&self) -> usize

pub fn consumer_task_count(&self) -> usize