pub struct DefaultChannelResolver { /* private fields */ }Expand description
Default implementation of a ChannelResolver that connects to the workers given the URL once and stores the connection instance in a TTI cache.
Sane default over which other ChannelResolver can be built for better customization of the WorkerServiceClients.
Implementations
Sourceimpl DefaultChannelResolver
impl DefaultChannelResolver
Sourcepub async fn get_channel(
&self,
url: &Url,
) -> Result<BoxCloneSyncChannel, DataFusionError>
pub async fn get_channel( &self, url: &Url, ) -> Result<BoxCloneSyncChannel, DataFusionError>
Gets the cached BoxCloneSyncChannel for the given URL, or builds a new one.