DistributedPhysicalOptimizerRule

Struct DistributedPhysicalOptimizerRule 

pub struct DistributedPhysicalOptimizerRule;
Physical optimizer rule that inspects the plan, places the appropriate network boundaries, and breaks it down into stages that can be executed in a distributed manner.

The rule has three steps:

  1. Annotate the plan with [annotate_plan]: adds some annotations to each node about how many distributed tasks should be used in the stage containing them, and whether they need a network boundary below or not. For more information about this step, read [annotate_plan] docs.

  2. Based on the [AnnotatedPlan] returned by [annotate_plan], place all the appropriate network boundaries (NetworkShuffleExec and NetworkCoalesceExec) with the task count assignation that the annotations required. After this, the plan is already a distributed executable plan.

  3. Place the [CoalesceBatchesExec] in the appropriate places (just below network boundaries), so that we send fewer and bigger record batches over the wire instead of a lot of small ones.