DistributedWorkUnitFeedContext

Struct DistributedWorkUnitFeedContext 

pub struct DistributedWorkUnitFeedContext {
    pub fan_out_tasks: usize,
}
Provides contextual information about where a WorkUnitFeedProvider is being executed. When using WorkUnitFeedProvider in distributed queries, it might be getting executed in the coordinating stage, or it might be getting executed just locally because the query did not need any remote execution.

Fields

fan_out_tasks: usize

The number of distributed tasks to which the WorkUnitFeedProvider should fan out.

Implementations

Source

impl DistributedWorkUnitFeedContext

pub fn from_ctx(ctx: &Arc<TaskContext>) -> Arc<Self>

Gets the DistributedWorkUnitFeedContext from the TaskContext as an extension. If no DistributedWorkUnitFeedContext is present, returns one valid for single-node execution.