pub struct ExecuteTaskRequest {
pub task_key: TaskKey,
pub target_partition_start: usize,
pub target_partition_end: usize,
pub producer_head: ProducerHead,
}Fields
task_key: TaskKeyThe unique identifier of the task that is going to get executed.
target_partition_start: usizeThe start of the partition range of the specified task that is going to be executed.
target_partition_end: usizeThe end of the partition range of the specified task that is going to be executed.
producer_head: ProducerHeadThe head node the requested task should have. Depending on the network boundary executing the task, the head node should be prepared differently, for example:
- A RepartitionExecHead implies a RepartitionExec at the head of the task.
- A BroadcastExecHead implies a BroadcastExec at the head of the task.
- A NoneHead does not need any specific head.