pub struct LocalWorkerContext { /* private fields */ }Expand description
Context injected to the datafusion::prelude::SessionConfig extensions that provides information about the presence of a Worker locally.
This information can be used for executing tasks locally bypassing remote comms if the tasks that needs to be remotely executed happens to be owned by this same worker.