SetPlanRequest

Struct SetPlanRequest 

pub struct SetPlanRequest {
    pub task_key: TaskKey,
    pub task_count: usize,
    pub plan: MaybeEncoded<Arc<dyn ExecutionPlan>>,
    pub work_unit_feed_declarations: Vec<WorkUnitFeedDeclaration>,
    pub target_worker_url: Url,
    pub query_start_time_ns: usize,
}

Fields

task_key: TaskKey

The unique identifier of the task to which the subplan belongs to.

task_count: usize

The amount of tasks that share the same subplan. Necessary for building the DistributedTaskContext during execution.

plan: MaybeEncoded<Arc<dyn ExecutionPlan>>

The subplan the worker is expected to execute.

work_unit_feed_declarations: Vec<WorkUnitFeedDeclaration>

Information about all the work unit feeds that will be streamed from coordinator to worker. This information is needed here because at the moment of setting the plan, all the appropriate channels for the incoming work unit feeds need to be constructed.

If no WorkUnitFeedExec nodes are present in the plan, this should be empty.

target_worker_url: Url

The worker URL to which this message will go. The receiving worker will use this information to identify itself, and avoid further calls in case it needs to call itself for executing tasks.

query_start_time_ns: usize

Unix nanos when the query started as reported by the coordinator. Used for collecting temporal metrics relative to when the query was fired in the coordinator.