pub struct TaskData { /* private fields */ }Expand description
TaskData stores state for a single task being executed by this Endpoint. It may be shared by concurrent requests for the same task which execute separate partitions.