TaskEstimation

Struct TaskEstimation 

pub struct TaskEstimation {
    pub task_count: TaskCountAnnotation,
}
Result of running a TaskEstimator on a leaf node. It tells the distributed planner hints about how many tasks should be used in [Stage]s that contain leaf nodes.

Fields

task_count: TaskCountAnnotation

The number of tasks that should be used in the [Stage] containing the leaf node.

Even if implementations get to decide this number, there are situations where it can get overridden:

  • If a [Stage] contains multiple leaf nodes, the one that declares the biggest task_count wins.
  • If there are less available workers than this number, the number of available workers is chosen.

Implementations

Source

impl TaskEstimation

pub fn maximum(value: usize) -> Self

Tells the distributed planner that the evaluated stage can have at maximum the provided number of tasks, setting a hard upper limit.

Returning TaskEstimation::maximum(1) tells the distributed planner that the evaluated stage cannot be distributed.

Even if a TaskEstimation::maximum(N) is provided, any other node in the same stage providing a value of TaskEstimation::maximum(M) where M < N will have preference.

pub fn desired(value: usize) -> Self

Tells the distributed planner that the evaluated can optimally have the provided number of tasks, setting a soft task count hint that can be overridden by others.

The provided TaskEstimation::desired(N) can be overridden by:

  • Other nodes providing a TaskEstimation::desired(M) where M > N.
  • Any other node providing a TaskEstimation::maximum(M) where M can be anything.