pub struct TaskMetrics {
pub pre_order_plan_metrics: Vec<MetricsSet>,
pub task_metrics: MetricsSet,
}Fields
pre_order_plan_metrics: Vec<MetricsSet>Metrics for a single task’s plan nodes in pre-order traversal order. The TaskKey is implicit — it is determined by the SetPlanRequest that opened this coordinator channel connection.
task_metrics: MetricsSetMetrics related to the execution of a task within a stage. This metrics, instead of being associated to a specific node, they are global to the task, like the time at which the plan was fed by the coordinator to the worker.