pub struct TaskProgress {
pub task_key: Option<TaskKey>,
pub total_partitions: u64,
pub completed_partitions: u64,
pub status: i32,
pub output_rows: u64,
}Expand description
Progress information for a single task
Fields
task_key: Option<TaskKey>total_partitions: u64completed_partitions: u64status: i32output_rows: u64Implementations
Sourceimpl TaskProgress
impl TaskProgress
Sourcepub fn status(&self) -> TaskStatus
pub fn status(&self) -> TaskStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: TaskStatus)
pub fn set_status(&mut self, value: TaskStatus)
Sets status to the provided enum value.