pub struct TaskRoutingContext<'a> {
pub task_ctx: Arc<TaskContext>,
pub plan: &'a Arc<dyn ExecutionPlan>,
pub task_count: usize,
pub available_urls: &'a [Url],
}Expand description
Context usable for routing tasks to worker URLs.
Fields
task_ctx: Arc<TaskContext>The task context active at routing time.
plan: &'a Arc<dyn ExecutionPlan>The head execution plan of the stage being routed.
task_count: usizeThe number of tasks to be assigned.
available_urls: &'a [Url]Contains a list of URLs representing machines available to receive a task. These URLs are sourced at execution time and thus should closely reflect the real state of the cluster.