pub struct WorkUnitMsg {
pub id: Uuid,
pub partition: usize,
pub body: MaybeEncoded<Box<dyn WorkUnit>>,
pub created_timestamp_unix_nanos: usize,
pub sent_timestamp_unix_nanos: usize,
pub received_timestamp_unix_nanos: usize,
pub processed_timestamp_unix_nanos: usize,
}Fields
id: UuidIdentifier of the node to which this work unit feed belongs to.
partition: usizeThe partition index within the node to which the work unit feed belongs to.
body: MaybeEncoded<Box<dyn WorkUnit>>Arbitrary user-defined data (e.g., a file address) necessary during execution.
created_timestamp_unix_nanos: usizeUnix timestamp in nanoseconds at which this message was created in the coordinator.
sent_timestamp_unix_nanos: usizeUnix timestamp in nanoseconds at which this message was sent by the coordinator.
received_timestamp_unix_nanos: usizeUnix timestamp in nanoseconds at which this message was received by a worker.
processed_timestamp_unix_nanos: usizeUnix timestamp in nanoseconds at which this message started being processed.