pub struct WorkerPlanRewriteEvent<'a> {
pub plan: Arc<dyn ExecutionPlan>,
pub session_config: &'a SessionConfig,
}Expand description
Information supplied while rewriting a decoded worker stage plan before registration.
Fields
plan: Arc<dyn ExecutionPlan>The worker-local plan. Each handler receives the plan returned by the previous handler.
session_config: &'a SessionConfigThe configuration of the worker session that will execute the plan.