GaugeMetricExt

Trait GaugeMetricExt 

pub trait GaugeMetricExt {
    // Required method
    fn max_gauge(self, name: impl Into<Cow<'static, str>>) -> MaxGaugeMetric;
}
Extension trait for DataFusion’s metric system that adds support for a Gauge metric that aggregates to others using max instead of sum

Required Methods

fn max_gauge(self, name: impl Into<Cow<'static, str>>) -> MaxGaugeMetric

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl GaugeMetricExt for MetricBuilder<'_>

Source

fn max_gauge(self, name: impl Into<Cow<'static, str>>) -> MaxGaugeMetric

Implementors