pub trait SessionStateBuilderExt {
// Required method
fn with_distributed_planner(self) -> Self;
}Expand description
Extension trait for SessionStateBuilder.
Required Methods
Sourcefn with_distributed_planner(self) -> Self
fn with_distributed_planner(self) -> Self
Injects a [QueryPlanner] implementation that attempts to distribute the plan after the normal planning passes are performed.
It will wrap the existing query planner if one, so while setting up DataFusion’s SessionStateBuilder, it’s important to inject the custom user query planner implementation with SessionStateBuilderExt::with_distributed_planner strictly before calling SessionStateBuilder::with_query_planner.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".