Physical optimizer rule that inspects the plan, places the appropriate network
boundaries, and breaks it down into stages that can be executed in a distributed manner.
A latency metric that captures only the first recorded value, ignoring all subsequent ones.
Uses 0 as the unset sentinel (valid durations are clamped to at least 1 nanosecond).
ExecutionPlan that coalesces partitions from multiple tasks into a one or more task without
performing any repartition, and maintaining the same partitioning scheme.
A unit of isolation for a portion of a physical execution plan
that can be executed independently and across a network boundary.
It implements ExecutionPlan and can be executed to produce a
stream of record batches.
TaskData stores state for a single task being executed by this Endpoint. It may be shared
by concurrent requests for the same task which execute separate partitions.
Result of running a TaskEstimator on a leaf node. It tells the distributed planner hints
about how many tasks should be used in [Stage]s that contain leaf nodes.
Label used to annotate metrics in execution plan nodes with the task in which they were executed.
Note that the same task id may be used in multiple stages.
Extension trait for DataFusion’s metric system that adds support for byte count metrics
that display using human-readable byte sizes (KB, MB, GB) instead of plain count notation.
Allows users to customize the way Worker clients are created. A common use case is to
wrap the client with tower layers or schedule it in an IO-specific tokio runtime.
This trait represents a node that introduces the necessity of a network boundary in the plan.
The distributed planner, upon stepping into one of these, will break the plan and build a stage
out of it.
Given a leaf node, provides an estimation about how many tasks should be used in the
stage containing it, and if the leaf node should be replaced by some other.
Rewrites a distributed plan with metrics. Does nothing if the root node is not a DistributedExec.
Returns an error if the distributed plan was not executed.