pub enum DistributedMetricsFormat {
Aggregated,
PerTask,
}Expand description
Format to use when displaying metrics for a distributed plan.
Variants
Aggregated
Metrics are aggregated across all tasks. ex. a output_rows=X represents the output rows for all tasks.
PerTask
Metric names are rewritten to include the task id. ex. output_rows -> output_rows_0, output_rows_1 etc.