Structs
- Default
Channel Resolver - Default implementation of a ChannelResolver that connects to the workers given the URL once and stores the connection instance in a TTI cache.
- GetCluster
Workers Request - GetCluster
Workers Response - GetTask
Progress Request - GetTask
Progress Response - Observability
Service Client - Observability
Service Impl - Observability
Service Server - Ping
Request - Ping
Response - Task
Progress - Progress information for a single task
- Worker
Metrics - Worker-level system metrics
Enums
Traits
- Observability
Service - Generated trait containing gRPC methods that should be implemented for use with ObservabilityServiceServer.
Functions
- create_
worker_ client - Creates a [
WorkerServiceClient] with high default message size limits.