pub struct DistributedLeafExec { /* private fields */ }Expand description
Represents a leaf node ready to be distributed across N tasks, where the variant of the node
belonging to each task is stored in a Vec of N positions.
While sending this plan over the wire to a remote worker, only the appropriate variant is sent.
This ExecutionPlan implementation is typically returned by [crate::TaskEstimator::scale_up_leaf_node], which will be called for scaling up a node for distribution. The process typically looks like this:
- The distributed planner calls [crate::TaskEstimator::scale_up_leaf_node] providing a leaf node and the amount of tasks in which it should be distributed:
┌──────────────┐
│DataSourceExec│ + 3 tasks
└──────────────┘- The [crate::TaskEstimator] implementation, either user provided or a default one, returns a DistributedLeafExec adhering to this task count:
┌────────────────────────────────────────────────┐
│ DistributedLeafExec │
│ │
│┌──────────────┐┌──────────────┐┌──────────────┐│
││DataSourceExec││DataSourceExec││DataSourceExec││
││ for task 0 ││ for task 1 ││ for task 2 ││
│└──────────────┘└──────────────┘└──────────────┘│
└────────────────────────────────────────────────┘- The crate::DistributedExec node, upon being executed, will send the different variants of the leaf node to the respective workers, instead of sending the full DistributedLeafExec:
┌──────────────────┐┌──────────────────┐┌──────────────────┐
│ Worker 0 ││ Worker 1 ││ Worker 2 │
│ ││ ││ │
│ ... ││ ... ││ ... │
│ ││ ││ │
│ ┌──────────────┐ ││ ┌──────────────┐ ││ ┌──────────────┐ │
│ │ SomeExec │ ││ │ SomeExec │ ││ │ SomeExec │ │
│ │ │ ││ │ │ ││ │ │ │
│ └──────────────┘ ││ └──────────────┘ ││ └──────────────┘ │
│ ┌──────────────┐ ││ ┌──────────────┐ ││ ┌──────────────┐ │
│ │DataSourceExec│ ││ │DataSourceExec│ ││ │DataSourceExec│ │
│ │ for task 0 │ ││ │ for task 1 │ ││ │ for task 2 │ │
│ └──────────────┘ ││ └──────────────┘ ││ └──────────────┘ │
└──────────────────┘└──────────────────┘└──────────────────┘This way, the different workers get to execute different versions of the same plan, each handling its own range of non-overlapping data.
Note that every variant in variants must agree on the same schema and partition count with
every other variant, but variants are not required to match the partition count of the
original leaf plan. Variants can scale their partition count higher or lower as needed for
worker execution.
Implementations
Sourceimpl DistributedLeafExec
impl DistributedLeafExec
Sourcepub fn try_new(
original: Arc<dyn ExecutionPlan>,
variants: impl IntoIterator<Item = Arc<dyn ExecutionPlan>>,
) -> Result<Self>
pub fn try_new( original: Arc<dyn ExecutionPlan>, variants: impl IntoIterator<Item = Arc<dyn ExecutionPlan>>, ) -> Result<Self>
Builds a new DistributedLeafExec based on the provided original plan and its per-task variants.
Every variant must expose the same schema and partition count as every other variant.
Variants do not need to match the partition count of the original plan.
Sourcepub fn original(&self) -> &Arc<dyn ExecutionPlan> ⓘ
pub fn original(&self) -> &Arc<dyn ExecutionPlan> ⓘ
The plan this leaf was built from (the leaf passed to
[crate::TaskEstimator::scale_up_leaf_node]). Useful for recognising which DistributedLeafExec
you are looking at — e.g. by downcasting it to your own leaf type — before inspecting its
DistributedLeafExec::variants.
Sourcepub fn variants(&self) -> &[Arc<dyn ExecutionPlan>]
pub fn variants(&self) -> &[Arc<dyn ExecutionPlan>]
The per-task variants, in task order: variants()[i] is the plan sent to task i. Useful
for inspecting per-task information (e.g. data locality) when routing tasks to workers via
[crate::TaskEstimator::route_tasks].