pub struct DistributedWorkUnitFeedContext {
pub fan_out_tasks: usize,
}Expand description
Provides contextual information about where a WorkUnitFeedProvider is being executed. When using WorkUnitFeedProvider in distributed queries, it might be getting executed in the coordinating stage, or it might be getting executed just locally because the query did not need any remote execution.
Fields
fan_out_tasks: usizeThe number of distributed tasks to which the WorkUnitFeedProvider should fan out.
Implementations
Sourceimpl DistributedWorkUnitFeedContext
impl DistributedWorkUnitFeedContext
Sourcepub fn from_ctx(ctx: &Arc<TaskContext>) -> Arc<Self> ⓘ
pub fn from_ctx(ctx: &Arc<TaskContext>) -> Arc<Self> ⓘ
Gets the DistributedWorkUnitFeedContext from the TaskContext as an extension. If no DistributedWorkUnitFeedContext is present, returns one valid for single-node execution.