pub struct LocalWorkerContext { /* private fields */ }Expand description
Context set by crate::Worker::coordinator_channel in DataFusion’s datafusion::prelude::SessionConfig that contains information about the local tasks the current crate::Worker owns.
This information can be used for executing tasks locally bypassing gRPC comms if the tasks that needs to be remotely executed happens to be owned by this same worker.