NetworkBroadcastExec

Struct NetworkBroadcastExec 

pub struct NetworkBroadcastExec { /* private fields */ }
Network boundary for broadcasting data to all consumer tasks.

This operator works with BroadcastExec which scales up partitions so each consumer task fetches a unique set of partition numbers. Each partition request is sent to all stage tasks because each task’s leaf node is specialized to serve a different slice of the data for the same logical partition number.

Here are some examples of how NetworkBroadcastExec distributes data:

1 to many

┌────────────────────────┐                        ┌────────────────────────┐           ■
│  NetworkBroadcastExec  │                        │  NetworkBroadcastExec  │           │
│        (task 1)        │           ...          │        (task M)        │           │
│                        │                        │                        │        Stage N
│    Populates Caches    │                        │    Populates Caches    │           │
└────────┬─┬┬─┬┬─┬───────┘                        └────────┬─┬┬─┬┬─┬───────┘           │
         │0││1││2│                                         │0││1││2│                   │
         └▲┘└▲┘└▲┘                                         └▲┘└▲┘└▲┘                   ■
          │  │  │                                           │  │  │
          │  │  │                                           │  │  │
          │  │  │                                           │  │  │
          │  │  └─────────────┐          ┌──────────────────┘  │  │
          │  └─────────────┐  │          │     ┌───────────────┘  │
          └─────────────┐  │  │          │     │    ┌─────────────┘
                        │  │  │          │     │    │
                       ┌┴┐┌┴┐┌┴┐ ... ┌───┴┐┌───┴┐┌──┴─┐
                       │1││2││3│     │NM-3││NM-2││NM-1│                                ■
                      ┌┴─┴┴─┴┴─┴─────┴────┴┴────┴┴────┴─┐                              │
                      │          BroadcastExec          │                              │
                      │        ┌───────────────┐        │                          Stage N-1
                      │        │  Batch Cache  │        │                              │
                      │        │  ┌─┐ ┌─┐ ┌─┐  │        │                              │
                      │        │  │0│ │1│ │2│  │        │                              │
                      │        │  └─┘ └─┘ └─┘  │        │                              │
                      │        └───────────────┘        │                              │
                      └───────────┬─┬─┬─┬─┬─┬───────────┘                              │
                                  │0│ │1│ │2│                                          │
                                  └▲┘ └▲┘ └▲┘                                          ■
                                   │   │   │
                                   │   │   │
                                   │   │   │
                                  ┌┴┐ ┌┴┐ ┌┴┐                                          ■
                                  │0│ │1│ │2│                                          │
                           ┌──────┴─┴─┴─┴─┴─┴──────┐                               Stage N-2
                           │Arc<dyn ExecutionPlan> │                                   │
                           │       (task 1)        │                                   │
                           └───────────────────────┘                                   ■

Many to many

   ┌────────────────────────┐                        ┌────────────────────────┐          ■
   │  NetworkBroadcastExec  │                        │  NetworkBroadcastExec  │          │
   │        (task 1)        │                        │        (task M)        │          │
   │                        │           ...          │                        │       Stage N
   │    Populates Caches    │                        │       Cache Hits       │          │
   └────────┬─┬┬─┬┬─┬───────┘                        └────────┬─┬┬─┬┬─┬───────┘          │
            │0││1││2│                                         │0││1││2│                  │
            └▲┘└▲┘└▲┘                                         └▲┘└▲┘└▲┘                  ■
             │  │  │                                           │  │  │
  ┌──────────┴──┼──┼────────────────────────────────┐          │  │  │
  │  ┌──────────┴──┼────────────────────────────────┼──┐       │  │  │
  │  │  ┌──────────┴────────────────────────────────┼──┼──┐    │  │  │
  │  │  │                                           │  │  │    │  │  │
  │  │  │         ┌─────────────────────────────────┼──┼──┼────┴──┼─┐│
  │  │  │         │     ┌───────────────────────────┼──┼──┼───────┴─┼┼─────┐
  │  │  │         │     │     ┌─────────────────────┼──┼──┼─────────┼┴─────┼────┐
  │  │  │         │     │     │                     │  │  │         │      │    │
 ┌┴┐┌┴┐┌┴┐ ... ┌──┴─┐┌──┴─┐┌──┴─┐                  ┌┴┐┌┴┐┌┴┐ ... ┌──┴─┐┌───┴┐┌──┴─┐      ■
 │0││1││2│     │3M-3││3M-2││3M-1│                  │0││1││2│     │3M-3││3M-2││3M-1│      │
┌┴─┴┴─┴┴─┴─────┴────┴┴────┴┴────┴┐                ┌┴─┴┴─┴┴─┴─────┴────┴┴────┴┴────┴┐     │
│         BroadcastExec          │                │         BroadcastExec          │     │
│        ┌───────────────┐       │                │        ┌───────────────┐       │     │
│        │  Batch Cache  │       │                │        │  Batch Cache  │       │     │
│        │  ┌─┐ ┌─┐ ┌─┐  │       │      ...       │        │  ┌─┐ ┌─┐ ┌─┐  │       │ Stage N-1
│        │  │0│ │1│ │2│  │       │                │        │  │0│ │1│ │2│  │       │     │
│        │  └─┘ └─┘ └─┘  │       │                │        │  └─┘ └─┘ └─┘  │       │     │
│        └───────────────┘       │                │        └───────────────┘       │     │
└───────────┬─┬─┬─┬─┬─┬──────────┘                └───────────┬─┬─┬─┬─┬─┬──────────┘     │
            │0│ │1│ │2│                                       │0│ │1│ │2│                │
            └▲┘ └▲┘ └▲┘                                       └▲┘ └▲┘ └▲┘                ■
             │   │   │                                         │   │   │
             │   │   │                                         │   │   │
             │   │   │                                         │   │   │
            ┌┴┐ ┌┴┐ ┌┴┐                                       ┌┴┐ ┌┴┐ ┌┴┐                ■
            │0│ │1│ │2│                                       │0│ │1│ │2│                │
     ┌──────┴─┴─┴─┴─┴─┴──────┐                         ┌──────┴─┴─┴─┴─┴─┴──────┐     Stage N-2
     │Arc<dyn ExecutionPlan> │          ...            │Arc<dyn ExecutionPlan> │         │
     │       (task 1)        │                         │       (task N)        │         │
     └───────────────────────┘                         └───────────────────────┘         ■

Notice in this diagram that each NetworkBroadcastExec sends a request to fetch data from each BroadcastExec in the stage below per partition. This is because each BroadcastExec has its own cache which contains partial results for the partition. It is the NetworkBroadcastExec’s job to merge these partial partitions to then broadcast complete data to the consumers.

Implementations

Source

impl NetworkBroadcastExec

pub fn try_new( input: Arc<dyn ExecutionPlan>, producer_tasks: usize, ) -> Result<Self>

Creates a new NetworkBroadcastExec fed by the provided BroadcastExec. The input plan will be executed in a remote worker in producer_tasks number of tasks.