pub struct NetworkBroadcastExec { /* private fields */ }Expand description
Network boundary for broadcasting data to all consumer tasks.
This operator works with [BroadcastExec] which scales up partitions so each consumer task fetches a unique set of partition numbers. Each partition request is sent to all stage tasks because PartitionIsolatorExec maps the same logical partition to different actual data on each task.
Here are some examples of how NetworkBroadcastExec distributes data:
1 to many
┌────────────────────────┐ ┌────────────────────────┐ ■
│ NetworkBroadcastExec │ │ NetworkBroadcastExec │ │
│ (task 1) │ ... │ (task M) │ │
│ │ │ │ Stage N
│ Populates Caches │ │ Populates Caches │ │
└────────┬─┬┬─┬┬─┬───────┘ └────────┬─┬┬─┬┬─┬───────┘ │
│0││1││2│ │0││1││2│ │
└▲┘└▲┘└▲┘ └▲┘└▲┘└▲┘ ■
│ │ │ │ │ │
│ │ │ │ │ │
│ │ │ │ │ │
│ │ └─────────────┐ ┌──────────────────┘ │ │
│ └─────────────┐ │ │ ┌───────────────┘ │
└─────────────┐ │ │ │ │ ┌─────────────┘
│ │ │ │ │ │
┌┴┐┌┴┐┌┴┐ ... ┌───┴┐┌───┴┐┌──┴─┐
│1││2││3│ │NM-3││NM-2││NM-1│ ■
┌┴─┴┴─┴┴─┴─────┴────┴┴────┴┴────┴─┐ │
│ BroadcastExec │ │
│ ┌───────────────┐ │ Stage N-1
│ │ Batch Cache │ │ │
│ │ ┌─┐ ┌─┐ ┌─┐ │ │ │
│ │ │0│ │1│ │2│ │ │ │
│ │ └─┘ └─┘ └─┘ │ │ │
│ └───────────────┘ │ │
└───────────┬─┬─┬─┬─┬─┬───────────┘ │
│0│ │1│ │2│ │
└▲┘ └▲┘ └▲┘ ■
│ │ │
│ │ │
│ │ │
┌┴┐ ┌┴┐ ┌┴┐ ■
│0│ │1│ │2│ │
┌──────┴─┴─┴─┴─┴─┴──────┐ Stage N-2
│Arc<dyn ExecutionPlan> │ │
│ (task 1) │ │
└───────────────────────┘ ■Many to many
┌────────────────────────┐ ┌────────────────────────┐ ■
│ NetworkBroadcastExec │ │ NetworkBroadcastExec │ │
│ (task 1) │ │ (task M) │ │
│ │ ... │ │ Stage N
│ Populates Caches │ │ Cache Hits │ │
└────────┬─┬┬─┬┬─┬───────┘ └────────┬─┬┬─┬┬─┬───────┘ │
│0││1││2│ │0││1││2│ │
└▲┘└▲┘└▲┘ └▲┘└▲┘└▲┘ ■
│ │ │ │ │ │
┌──────────┴──┼──┼────────────────────────────────┐ │ │ │
│ ┌──────────┴──┼────────────────────────────────┼──┐ │ │ │
│ │ ┌──────────┴────────────────────────────────┼──┼──┐ │ │ │
│ │ │ │ │ │ │ │ │
│ │ │ ┌─────────────────────────────────┼──┼──┼────┴──┼─┐│
│ │ │ │ ┌───────────────────────────┼──┼──┼───────┴─┼┼─────┐
│ │ │ │ │ ┌─────────────────────┼──┼──┼─────────┼┴─────┼────┐
│ │ │ │ │ │ │ │ │ │ │ │
┌┴┐┌┴┐┌┴┐ ... ┌──┴─┐┌──┴─┐┌──┴─┐ ┌┴┐┌┴┐┌┴┐ ... ┌──┴─┐┌───┴┐┌──┴─┐ ■
│0││1││2│ │3M-3││3M-2││3M-1│ │0││1││2│ │3M-3││3M-2││3M-1│ │
┌┴─┴┴─┴┴─┴─────┴────┴┴────┴┴────┴┐ ┌┴─┴┴─┴┴─┴─────┴────┴┴────┴┴────┴┐ │
│ BroadcastExec │ │ BroadcastExec │ │
│ ┌───────────────┐ │ │ ┌───────────────┐ │ │
│ │ Batch Cache │ │ │ │ Batch Cache │ │ │
│ │ ┌─┐ ┌─┐ ┌─┐ │ │ ... │ │ ┌─┐ ┌─┐ ┌─┐ │ │ Stage N-1
│ │ │0│ │1│ │2│ │ │ │ │ │0│ │1│ │2│ │ │ │
│ │ └─┘ └─┘ └─┘ │ │ │ │ └─┘ └─┘ └─┘ │ │ │
│ └───────────────┘ │ │ └───────────────┘ │ │
└───────────┬─┬─┬─┬─┬─┬──────────┘ └───────────┬─┬─┬─┬─┬─┬──────────┘ │
│0│ │1│ │2│ │0│ │1│ │2│ │
└▲┘ └▲┘ └▲┘ └▲┘ └▲┘ └▲┘ ■
│ │ │ │ │ │
│ │ │ │ │ │
│ │ │ │ │ │
┌┴┐ ┌┴┐ ┌┴┐ ┌┴┐ ┌┴┐ ┌┴┐ ■
│0│ │1│ │2│ │0│ │1│ │2│ │
┌──────┴─┴─┴─┴─┴─┴──────┐ ┌──────┴─┴─┴─┴─┴─┴──────┐ Stage N-2
│Arc<dyn ExecutionPlan> │ ... │Arc<dyn ExecutionPlan> │ │
│ (task 1) │ │ (task N) │ │
└───────────────────────┘ └───────────────────────┘ ■Notice in this diagram that each NetworkBroadcastExec sends a request to fetch data from each [BroadcastExec] in the stage below per partition. This is because each [BroadcastExec] has its own cache which contains partial results for the partition. It is the NetworkBroadcastExec’s job to merge these partial partitions to then broadcast complete data to the consumers.
Implementations
Sourceimpl NetworkBroadcastExec
impl NetworkBroadcastExec
Sourcepub fn try_new(
input: Arc<dyn ExecutionPlan>,
query_id: Uuid,
stage_num: usize,
consumer_task_count: usize,
input_task_count: usize,
) -> Result<Self, DataFusionError>
pub fn try_new( input: Arc<dyn ExecutionPlan>, query_id: Uuid, stage_num: usize, consumer_task_count: usize, input_task_count: usize, ) -> Result<Self, DataFusionError>
Creates a NetworkBroadcastExec.
Extracts its child, a BroadcastExec, and creates a new BroadcastExec with the correct consumer_task_count.