NetworkCoalesceExec

Struct NetworkCoalesceExec 

pub struct NetworkCoalesceExec { /* private fields */ }
ExecutionPlan that coalesces partitions from multiple tasks into a one or more task without performing any repartition, and maintaining the same partitioning scheme.

This is the equivalent of a [CoalescePartitionsExec] but coalescing tasks across the network between distributed stages.

                               ┌───────────────────────────┐                                   ■
                               │    NetworkCoalesceExec    │                                   │
                               │         (task 1)          │                                   │
                               └┬─┬┬─┬┬─┬┬─┬┬─┬┬─┬┬─┬┬─┬┬─┬┘                                Stage N+1
                                │1││2││3││4││5││6││7││8││9│                                    │
                                └─┘└─┘└─┘└─┘└─┘└─┘└─┘└─┘└─┘                                    │
                                ▲  ▲  ▲   ▲  ▲  ▲   ▲  ▲  ▲                                    ■
  ┌──┬──┬───────────────────────┴──┴──┘   │  │  │   └──┴──┴──────────────────────┬──┬──┐
  │  │  │                                 │  │  │                                │  │  │       ■
 ┌─┐┌─┐┌─┐                               ┌─┐┌─┐┌─┐                              ┌─┐┌─┐┌─┐      │
 │1││2││3│                               │4││5││6│                              │7││8││9│      │
┌┴─┴┴─┴┴─┴──────────────────┐  ┌─────────┴─┴┴─┴┴─┴─────────┐ ┌──────────────────┴─┴┴─┴┴─┴┐  Stage N
│  Arc<dyn ExecutionPlan>   │  │  Arc<dyn ExecutionPlan>   │ │  Arc<dyn ExecutionPlan>   │     │
│         (task 1)          │  │         (task 2)          │ │         (task 3)          │     │
└───────────────────────────┘  └───────────────────────────┘ └───────────────────────────┘     ■

The communication between two stages across a NetworkCoalesceExec has two implications:

  • Stage N+1 may have one or more tasks. Each consumer task reads a contiguous group of upstream tasks from Stage N.
  • Output partitioning for Stage N+1 is sized based on the maximum upstream-group size. When groups are uneven, consumer tasks with smaller groups return empty streams for the “extra” partitions.
                   ┌───────────────────────────┐        ┌───────────────────────────┐          ■
                   │    NetworkCoalesceExec    │        │    NetworkCoalesceExec    │          │
                   │         (task 1)          │        │         (task 2)          │          │
                   └┬─┬┬─┬┬─┬┬─┬┬─┬┬─┬─────────┘        └┬─┬┬─┬┬─┬┬─┬┬─┬┬─┬─────────┘       Stage N+1
                    │1││2││3││4││5││6│                   │7││8││9││_││_││_│                    │
                    └─┘└─┘└─┘└─┘└─┘└─┘                   └─┘└─┘└─┘└─┘└─┘└─┘                    │
                     ▲  ▲  ▲  ▲  ▲  ▲                     ▲  ▲  ▲                              ■
  ┌──┬──┬────────────┴──┴──┘  └──┴──┴─────┬──┬──┐         └──┴──┴────────────────┬──┬──┐
  │  │  │                                 │  │  │                                │  │  │       ■
 ┌─┐┌─┐┌─┐                               ┌─┐┌─┐┌─┐                              ┌─┐┌─┐┌─┐      │
 │1││2││3│                               │4││5││6│                              │7││8││9│      │
┌┴─┴┴─┴┴─┴──────────────────┐  ┌─────────┴─┴┴─┴┴─┴─────────┐ ┌──────────────────┴─┴┴─┴┴─┴┐  Stage N
│  Arc<dyn ExecutionPlan>   │  │  Arc<dyn ExecutionPlan>   │ │  Arc<dyn ExecutionPlan>   │     │
│         (task 1)          │  │         (task 2)          │ │         (task 3)          │     │
└───────────────────────────┘  └───────────────────────────┘ └───────────────────────────┘     ■

This node has two variants.

  1. Pending: acts as a placeholder for the distributed optimization step to mark it as ready.
  2. Ready: runs within a distributed stage and queries the next input stage over the network using Arrow Flight.

Implementations

Source

impl NetworkCoalesceExec

pub fn try_new( input: Arc<dyn ExecutionPlan>, query_id: Uuid, num: usize, task_count: usize, input_task_count: usize, ) -> Result<Self>

Builds a new NetworkCoalesceExec in “Pending” state.

Typically, this node should be placed right after nodes that coalesce all the input partitions into one, for example:

  • [CoalescePartitionsExec]
  • [SortPreservingMergeExec]