NetworkShuffleExec

Struct NetworkShuffleExec 

pub struct NetworkShuffleExec { /* private fields */ }
ExecutionPlan implementation that shuffles data across the network in a distributed context.

The easiest way of thinking about this node is as a plan RepartitionExec node that is capable of fanning out the different produced partitions to different tasks. This allows redistributing data across different tasks in different stages, so that different physical machines can make progress on different non-overlapping sets of data.

This node allows fanning out of data from N tasks to M tasks, with N and M being arbitrary non-zero positive numbers. Here are some examples of how data can be shuffled in different scenarios:

1 to many

┌───────────────────────────┐  ┌───────────────────────────┐ ┌───────────────────────────┐     ■
│    NetworkShuffleExec     │  │    NetworkShuffleExec     │ │    NetworkShuffleExec     │     │
│         (task 1)          │  │         (task 2)          │ │         (task 3)          │     │
└┬─┬┬─┬┬─┬──────────────────┘  └─────────┬─┬┬─┬┬─┬─────────┘ └──────────────────┬─┬┬─┬┬─┬┘  Stage N+1
 │1││2││3│                               │4││5││6│                              │7││8││9│      │
 └─┘└─┘└─┘                               └─┘└─┘└─┘                              └─┘└─┘└─┘      │
  ▲  ▲  ▲                                 ▲  ▲  ▲                                ▲  ▲  ▲       ■
  └──┴──┴────────────────────────┬──┬──┐  │  │  │  ┌──┬──┬───────────────────────┴──┴──┘
                                 │  │  │  │  │  │  │  │  │                                     ■
                                ┌─┐┌─┐┌─┐┌─┐┌─┐┌─┐┌─┐┌─┐┌─┐                                    │
                                │1││2││3││4││5││6││7││8││9│                                    │
                               ┌┴─┴┴─┴┴─┴┴─┴┴─┴┴─┴┴─┴┴─┴┴─┴┐                                Stage N
                               │      RepartitionExec      │                                   │
                               │         (task 1)          │                                   │
                               └───────────────────────────┘                                   ■

many to 1

                               ┌───────────────────────────┐                                   ■
                               │    NetworkShuffleExec     │                                   │
                               │         (task 1)          │                                   │
                               └┬─┬┬─┬┬─┬┬─┬┬─┬┬─┬┬─┬┬─┬┬─┬┘                                Stage N+1
                                │1││2││3││4││5││6││7││8││9│                                    │
                                └─┘└─┘└─┘└─┘└─┘└─┘└─┘└─┘└─┘                                    │
                                ▲▲▲▲▲▲▲▲▲▲▲▲▲▲▲▲▲▲▲▲▲▲▲▲▲▲▲                                    ■
  ┌──┬──┬──┬──┬──┬──┬──┬──┬─────┴┼┴┴┼┴┴┼┴┴┼┴┴┼┴┴┼┴┴┼┴┴┼┴┴┼┴────┬──┬──┬──┬──┬──┬──┬──┬──┐
  │  │  │  │  │  │  │  │  │      │  │  │  │  │  │  │  │  │     │  │  │  │  │  │  │  │  │       ■
 ┌─┐┌─┐┌─┐┌─┐┌─┐┌─┐┌─┐┌─┐┌─┐    ┌─┐┌─┐┌─┐┌─┐┌─┐┌─┐┌─┐┌─┐┌─┐   ┌─┐┌─┐┌─┐┌─┐┌─┐┌─┐┌─┐┌─┐┌─┐      │
 │1││2││3││4││5││6││7││8││9│    │1││2││3││4││5││6││7││8││9│   │1││2││3││4││5││6││7││8││9│      │
┌┴─┴┴─┴┴─┴┴─┴┴─┴┴─┴┴─┴┴─┴┴─┴┐  ┌┴─┴┴─┴┴─┴┴─┴┴─┴┴─┴┴─┴┴─┴┴─┴┐ ┌┴─┴┴─┴┴─┴┴─┴┴─┴┴─┴┴─┴┴─┴┴─┴┐  Stage N
│      RepartitionExec      │  │      RepartitionExec      │ │      RepartitionExec      │     │
│         (task 1)          │  │         (task 2)          │ │         (task 3)          │     │
└───────────────────────────┘  └───────────────────────────┘ └───────────────────────────┘     ■

many to many

                   ┌───────────────────────────┐  ┌───────────────────────────┐                ■
                   │    NetworkShuffleExec     │  │    NetworkShuffleExec     │                │
                   │         (task 1)          │  │         (task 2)          │                │
                   └┬─┬┬─┬┬─┬┬─┬───────────────┘  └───────────────┬─┬┬─┬┬─┬┬─┬┘             Stage N+1
                    │1││2││3││4│                                  │5││6││7││8│                 │
                    └─┘└─┘└─┘└─┘                                  └─┘└─┘└─┘└─┘                 │
                    ▲▲▲▲▲▲▲▲▲▲▲▲                                  ▲▲▲▲▲▲▲▲▲▲▲▲                 ■
    ┌──┬──┬──┬──┬──┬┴┴┼┴┴┼┴┴┴┴┴┴───┬──┬──┬──┬──┬──┬──┬──┬────────┬┴┴┼┴┴┼┴┴┼┴┴┼──┬──┬──┐
    │  │  │  │  │  │  │  │         │  │  │  │  │  │  │  │        │  │  │  │  │  │  │  │        ■
   ┌─┐┌─┐┌─┐┌─┐┌─┐┌─┐┌─┐┌─┐       ┌─┐┌─┐┌─┐┌─┐┌─┐┌─┐┌─┐┌─┐      ┌─┐┌─┐┌─┐┌─┐┌─┐┌─┐┌─┐┌─┐       │
   │1││2││3││4││5││6││7││8│       │1││2││3││4││5││6││7││8│      │1││2││3││4││5││6││7││8│       │
┌──┴─┴┴─┴┴─┴┴─┴┴─┴┴─┴┴─┴┴─┴─┐  ┌──┴─┴┴─┴┴─┴┴─┴┴─┴┴─┴┴─┴┴─┴─┐ ┌──┴─┴┴─┴┴─┴┴─┴┴─┴┴─┴┴─┴┴─┴─┐  Stage N
│      RepartitionExec      │  │      RepartitionExec      │ │      RepartitionExec      │     │
│         (task 1)          │  │         (task 2)          │ │         (task 3)          │     │
└───────────────────────────┘  └───────────────────────────┘ └───────────────────────────┘     ■

The communication between two stages across a NetworkShuffleExec has two implications:

  • Each task in Stage N+1 gathers data from all tasks in Stage N
  • The total number of partitions across all tasks in Stage N+1 is equal to the number of partitions in a single task in Stage N. (e.g. (1,2,3,4)+(5,6,7,8) = (1,2,3,4,5,6,7,8) )

This node has two variants.

  1. Pending: acts as a placeholder for the distributed optimization step to mark it as ready.
  2. Ready: runs within a distributed stage and queries the next input stage over the network using Arrow Flight.

Implementations

Source

impl NetworkShuffleExec

pub fn try_new( input: Arc<dyn ExecutionPlan>, query_id: Uuid, num: usize, task_count: usize, input_task_count: usize, ) -> Result<Self, DataFusionError>

Builds a new NetworkShuffleExec in “Pending” state.

Typically, the input to this node is a RepartitionExec with a Partitioning::Hash partition scheme.