pub trait MappedWorkerSessionBuilderExt {
// Required method
fn map<F>(self, f: F) -> MappedWorkerSessionBuilder<Self, F>
where Self: Sized,
F: Fn(SessionStateBuilder) -> Result<SessionState, DataFusionError>;
}Required Methods
Sourcefn map<F>(self, f: F) -> MappedWorkerSessionBuilder<Self, F>
fn map<F>(self, f: F) -> MappedWorkerSessionBuilder<Self, F>
Maps an existing WorkerSessionBuilder allowing to add further extensions to its already built SessionStateBuilder.
Useful if there’s already a WorkerSessionBuilder that needs to be extended with further capabilities.
Example:
let session_builder = DefaultSessionBuilder
.map(|b: SessionStateBuilder| {
// Add further things.
Ok(b.build())
});Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".