NetworkBoundary

Trait NetworkBoundary 

pub trait NetworkBoundary: ExecutionPlan {
    // Required methods
    fn with_input_stage(
        &self,
        input_stage: Stage,
    ) -> Result<Arc<dyn ExecutionPlan>>;
    fn input_stage(&self) -> &Stage;
}
This trait represents a node that introduces the necessity of a network boundary in the plan. The distributed planner, upon stepping into one of these, will break the plan and build a stage out of it.

Required Methods

fn with_input_stage(&self, input_stage: Stage) -> Result<Arc<dyn ExecutionPlan>>

Called when a Stage is correctly formed. The NetworkBoundary can use this information to perform any internal transformations necessary for distributed execution.

Typically, NetworkBoundarys will use this call for transitioning from “Pending” to “ready”.

fn input_stage(&self) -> &Stage

Returns the assigned input Stage, if any.

Implementors